@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #include "e.h"
 
 static Ecore_Exe *_e_intl_input_method_exec = NULL;
@@ -21,8 +18,8 @@ static char *_e_intl_orig_gtk_im_module = NULL;
 static const char *_e_intl_imc_personal_path = NULL;
 static const char *_e_intl_imc_system_path = NULL;
 
-#define E_EXE_STOP(EXE) if (EXE != NULL) { ecore_exe_terminate(EXE); ecore_exe_free(EXE); EXE = NULL; }
-#define E_EXE_IS_VALID(EXE) (!((EXE == NULL) || (EXE[0] == 0)))
+#define E_EXE_STOP(EXE) if (EXE) { ecore_exe_terminate(EXE); ecore_exe_free(EXE); EXE = NULL; }
+#define E_EXE_IS_VALID(EXE) (!((!EXE) || (EXE[0] == 0)))
 
 /* All locale parts */
 #define E_INTL_LOC_ALL		E_INTL_LOC_LANG | \
@@ -30,7 +27,7 @@ static const char *_e_intl_imc_system_path = NULL;
 				E_INTL_LOC_CODESET | \
 				E_INTL_LOC_MODIFIER
 
-/* Locale parts wich are significant when Validating */
+/* Locale parts which are significant when Validating */
 #define E_INTL_LOC_SIGNIFICANT	E_INTL_LOC_LANG | \
 				E_INTL_LOC_REGION | \
 				E_INTL_LOC_CODESET
@@ -47,13 +44,13 @@ static Eina_List	*_e_intl_locale_system_locales_get(void);
 static Eina_List	*_e_intl_locale_search_order_get(const char *locale);
 static int		 _e_intl_locale_validate(const char *locale);
 static void 		 _e_intl_locale_hash_free(Eina_Hash *language_hash);
-static Evas_Bool 	 _e_intl_locale_hash_free_cb(const Eina_Hash *hash, const void *key, void *data, void *fdata);
+static Eina_Bool 	 _e_intl_locale_hash_free_cb(const Eina_Hash *hash, const void *key, void *data, void *fdata);
 
 /* Input Method Configuration and Management */
-static int 		 _e_intl_cb_exit(void *data, int type, void *event);
+static Eina_Bool	 _e_intl_cb_exit(void *data, int type, void *event);
 static Eina_List 	*_e_intl_imc_dir_scan(const char *dir);
 
-EAPI int
+EINTERN int
 e_intl_init(void)
 {
    char *s;
@@ -72,7 +69,7 @@ e_intl_init(void)
    return 1;
 }
 
-EAPI int
+EINTERN int
 e_intl_shutdown(void)
 {
    E_FREE(_e_intl_language);
@@ -96,7 +93,7 @@ e_intl_shutdown(void)
 }
 
 /* Setup configuration settings and start services */
-EAPI int
+EINTERN int
 e_intl_post_init(void)
 {
    if ((e_config->language) && (e_config->language[0] != 0))
@@ -112,7 +109,7 @@ e_intl_post_init(void)
    return 1;
 }
 
-EAPI int
+EINTERN int
 e_intl_post_shutdown(void)
 {
    if (_e_intl_exit_handler)
@@ -212,14 +209,14 @@ e_intl_language_set(const char *lang)
              char *locale_path;
 
              locale_path = _e_intl_language_path_find(_e_intl_language_alias);
-             if (locale_path == NULL)
+             if (!locale_path)
 	       {
 		  E_Locale_Parts *locale_parts;
 
 		  locale_parts = e_intl_locale_parts_get(_e_intl_language_alias);
 
 		  /* If locale is C or some form of en don't report an error */
-		  if ((locale_parts == NULL) && 
+		  if ((!locale_parts) && 
 		      (strcmp(_e_intl_language_alias, "C")))
 		    {
 		       fprintf(stderr,
@@ -251,9 +248,11 @@ e_intl_language_set(const char *lang)
 	       }
 	     else
 	       {
+#ifdef HAVE_GETTEXT
 		  bindtextdomain(PACKAGE, locale_path);
 		  textdomain(PACKAGE);
 		  bind_textdomain_codeset(PACKAGE, "UTF-8");
+#endif
 		  free(locale_path);
                }
 	  }
@@ -285,7 +284,7 @@ e_intl_language_list(void)
    EINA_LIST_FOREACH(dir_list, next, epd)
      {
 	Eina_List *dir_languages;
-	     char *language;
+	char *language;
 
 	dir_languages = _e_intl_language_dir_scan(epd->dir);
 
@@ -310,11 +309,10 @@ _e_intl_language_list_find(Eina_List *language_list, char *language)
    Eina_List *l;
    char *lang;
 
-   if (!language_list) return 0;
-   if (!language) return 0;
+   if ((!language_list) || (!language)) return 0;
 
    EINA_LIST_FOREACH(language_list, l, lang)
-	if (!strcmp(lang, language)) return 1;
+     if (!strcmp(lang, language)) return 1;
 
    return 0;
 }
@@ -360,7 +358,6 @@ e_intl_input_method_set(const char *imc_path)
 			   (!ecore_exe_pid_get(_e_intl_input_method_exec)))
 			 e_util_dialog_show(_("Input Method Error"),
 					    _( "Error starting the input method executable<br><br>"
-
 					       "please make sure that your input<br>"
 					       "method configuration is correct and<br>"
 					       "that your configuration's<br>"
@@ -393,7 +390,7 @@ e_intl_input_method_list(void)
 const char *
 e_intl_imc_personal_path_get(void)
 {
-   if (_e_intl_imc_personal_path == NULL)
+   if (!_e_intl_imc_personal_path)
      {
 	char buf[4096];
 
@@ -406,7 +403,7 @@ e_intl_imc_personal_path_get(void)
 const char *
 e_intl_imc_system_path_get(void)
 {
-   if (_e_intl_imc_system_path == NULL)
+   if (!_e_intl_imc_system_path)
      {
 	char buf[4096];
 
@@ -416,19 +413,19 @@ e_intl_imc_system_path_get(void)
    return _e_intl_imc_system_path;
 }
 
-static int
-_e_intl_cb_exit(void *data, int type, void *event)
+static Eina_Bool
+_e_intl_cb_exit(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Exe_Event_Del *ev;
 
    ev = event;
-   if (!ev->exe) return 1;
+   if (!ev->exe) return ECORE_CALLBACK_PASS_ON;
 
    if (!(ecore_exe_tag_get(ev->exe) &&
-	(!strcmp(ecore_exe_tag_get(ev->exe), "E/im_exec")))) return 1;
+	 (!strcmp(ecore_exe_tag_get(ev->exe), "E/im_exec")))) return 1;
 
    _e_intl_input_method_exec = NULL;
-   return 1;
+   return ECORE_CALLBACK_PASS_ON;
 }
 
 static void
@@ -466,29 +463,28 @@ _e_intl_language_path_find(char *language)
    Eina_List	*search_list;
    Eina_List	*next_dir;
    Eina_List	*next_search;
+   E_Path_Dir	*epd;
+   char		*search_locale;
    int		 found;
 
    search_list = _e_intl_locale_search_order_get(language);
 
-   if (search_list == NULL) return NULL;
+   if (!search_list) return NULL;
 
    directory = NULL;
    found = 0;
    dir_list = e_path_dir_list_get(path_messages);
 
    /* For each directory in the path */
-   for (next_dir = dir_list; next_dir && !found; next_dir = next_dir->next)
+   EINA_LIST_FOREACH(dir_list, next_dir, epd)
      {
-	E_Path_Dir *epd;
-	epd = next_dir->data;
+	if (found) break;
 
 	/* Match canonicalized locale against each possible search */
-	for (next_search = search_list; next_search && !found; next_search = next_search->next)
+	EINA_LIST_FOREACH(search_list, next_search, search_locale)
 	  {
-	     char *search_locale;
 	     char message_path[PATH_MAX];
 
-	     search_locale = next_search->data;
 	     snprintf(message_path, sizeof(message_path), "%s/%s/LC_MESSAGES/%s.mo", epd->dir, search_locale, PACKAGE);
 
 	     if ((ecore_file_exists(message_path)) && (!ecore_file_is_dir(message_path)))
@@ -502,7 +498,7 @@ _e_intl_language_path_find(char *language)
    e_path_dir_list_free(dir_list);
 
    EINA_LIST_FREE(search_list, data)
-	free(data);
+     free(data);
 
    return directory;
 }
@@ -526,7 +522,7 @@ _e_intl_language_dir_scan(const char *dir)
 	     char file_path[PATH_MAX];
 
 	     snprintf(file_path, sizeof(file_path),"%s/%s/LC_MESSAGES/%s.mo",
-		   dir, file, PACKAGE);
+		      dir, file, PACKAGE);
 	     if (ecore_file_exists(file_path) && !ecore_file_is_dir(file_path))
 	       languages = eina_list_append(languages, file);
 	     else
@@ -548,13 +544,13 @@ _e_intl_locale_alias_get(const char *language)
    Eina_Hash *alias_hash;
    char *alias;
    char *lower_language;
-   int i;
+   unsigned int i;
 
-   if ((language == NULL) || (!strncmp(language, "POSIX", strlen("POSIX"))))
+   if ((!language) || (!strncmp(language, "POSIX", strlen("POSIX"))))
      return strdup("C");
 
    alias_hash = _e_intl_locale_alias_hash_get();
-   if (alias_hash == NULL) /* No alias file available */
+   if (!alias_hash) /* No alias file available */
      return strdup(language);
 
    lower_language = malloc(strlen(language) + 1);
@@ -580,19 +576,17 @@ _e_intl_locale_alias_hash_get(void)
 {
    Eina_List *next;
    Eina_List *dir_list;
+   E_Path_Dir *epd;
    Eina_Hash *alias_hash;
 
    dir_list = e_path_dir_list_get(path_messages);
    alias_hash = NULL;
 
-   for (next = dir_list; next; next = next->next)
+   EINA_LIST_FOREACH(dir_list, next, epd)
      {
 	char buf[4096];
-	E_Path_Dir *epd;
 	FILE *f;
 
-	epd = next->data;
-
 	snprintf(buf, sizeof(buf), "%s/locale.alias", epd->dir);
 	f = fopen(buf, "r");
 	if (f)
@@ -642,7 +636,7 @@ e_intl_locale_parts_get(const char *locale)
 
    /* Parse State */
    int   state = 0; /* start out looking for the language */
-   int   locale_idx;
+   unsigned int locale_idx;
    int   tmp_idx = 0;
 
    /* Parse Loop - Seperators are _ . @ */
@@ -761,7 +755,7 @@ e_intl_locale_parts_get(const char *locale)
 EAPI void
 e_intl_locale_parts_free(E_Locale_Parts *locale_parts)
 {
-   if (locale_parts != NULL)
+   if (locale_parts)
      {
 	if (locale_parts->lang) eina_stringshare_del(locale_parts->lang);
 	if (locale_parts->region) eina_stringshare_del(locale_parts->region);
@@ -887,7 +881,7 @@ _e_intl_locale_validate(const char *locale)
    locale_lr = 
      e_intl_locale_parts_combine(locale_parts, 
 				 E_INTL_LOC_LANG | E_INTL_LOC_REGION);
-   if (locale_lr == NULL)
+   if (!locale_lr)
      {
 	/* Not valid locale, maybe its an alias */
 	locale_lr = strdup(locale);
@@ -920,7 +914,7 @@ _e_intl_locale_validate(const char *locale)
 		 (!strcmp(locale_lr, locale_lr_next)))
 	       {
 		  /* Matched lang/region part, now if CS matches */
-		  if ((locale_parts->codeset == NULL) && (locale_parts_next->codeset == NULL))
+		  if ((!locale_parts->codeset) && (!locale_parts_next->codeset))
 		    {
 		       /* Lang/Region parts match and no charsets,
 			* we have a match
@@ -1001,7 +995,7 @@ _e_intl_locale_search_order_get(const char *locale)
    int mask;
 
    locale_parts = e_intl_locale_parts_get(locale);
-   if (locale_parts == NULL) return NULL;
+   if (!locale_parts) return NULL;
 
    search_list = NULL;
    for (mask = E_INTL_LOC_ALL; mask >= E_INTL_LOC_LANG; mask--)
@@ -1027,16 +1021,15 @@ _e_intl_imc_dir_scan(const char *dir)
    files = ecore_file_ls(dir);
 
    EINA_LIST_FREE(files, file)
+     {
+	if (strstr(file, ".imc"))
 	  {
-	     if (strstr(file, ".imc") != NULL)
-	       {
-		  char buf[PATH_MAX];
-
-		  snprintf(buf, sizeof(buf), "%s/%s", dir, file);
-		  imcs = eina_list_append(imcs, strdup(buf));
-	       }
-	free(file);
+	     char buf[PATH_MAX];
+	     
+	     snprintf(buf, sizeof(buf), "%s/%s", dir, file);
+	     imcs = eina_list_append(imcs, strdup(buf));
 	  }
-
+	free(file);
+     }
    return imcs;
 }
