@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #include "e.h"
 
 typedef struct _E_Smart_Data E_Smart_Data;
@@ -176,7 +173,7 @@ e_table_col_row_size_get(Evas_Object *obj, int *cols, int *rows)
 }
 
 EAPI void
-e_table_min_size_get(Evas_Object *obj, Evas_Coord *minw, Evas_Coord *minh)
+e_table_size_min_get(Evas_Object *obj, Evas_Coord *minw, Evas_Coord *minh)
 {
    E_Smart_Data *sd;
    
@@ -187,7 +184,7 @@ e_table_min_size_get(Evas_Object *obj, Evas_Coord *minw, Evas_Coord *minh)
 }
 
 EAPI void
-e_table_max_size_get(Evas_Object *obj, Evas_Coord *maxw, Evas_Coord *maxh)
+e_table_size_max_get(Evas_Object *obj, Evas_Coord *maxw, Evas_Coord *maxh)
 {
    E_Smart_Data *sd;
    
@@ -246,12 +243,12 @@ _e_table_smart_adopt(E_Smart_Data *sd, Evas_Object *obj)
    ti->max.w = 0;
    ti->max.h = 0;
    evas_object_clip_set(obj, sd->clip);
-   evas_object_stack_above(obj, sd->obj);
+//   evas_object_stack_above(obj, sd->obj);
    evas_object_smart_member_add(obj, ti->sd->obj);
    evas_object_data_set(obj, "e_table_data", ti);
    evas_object_event_callback_add(obj, EVAS_CALLBACK_FREE,
 				  _e_table_smart_item_del_hook, NULL);
-   evas_object_stack_below(obj, sd->obj);
+//   evas_object_stack_below(obj, sd->obj);
    if ((!evas_object_visible_get(sd->clip)) &&
        (evas_object_visible_get(sd->obj)))
      evas_object_show(sd->clip);
@@ -279,7 +276,7 @@ _e_table_smart_disown(Evas_Object *obj)
 }
 
 static void
-_e_table_smart_item_del_hook(void *data, Evas *e, Evas_Object *obj, void *event_info)
+_e_table_smart_item_del_hook(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj, void *event_info __UNUSED__)
 {
    e_table_unpack(obj);
 }
@@ -289,6 +286,7 @@ _e_table_smart_reconfigure(E_Smart_Data *sd)
 {
    Evas_Coord x, y, w, h, xx, yy;
    Eina_List *l;
+   Evas_Object *obj;
    int minw, minh, expandw, expandh;
 
    if (!sd->changed) return;
@@ -314,37 +312,31 @@ _e_table_smart_reconfigure(E_Smart_Data *sd)
 	y = y + ((h - minh) * (1.0 - sd->align.y));
 	h = minh;
      }
-   for (l = sd->items; l; l = l->next)
+   EINA_LIST_FOREACH(sd->items, l, obj)
      {
 	E_Table_Item *ti;
-	Evas_Object *obj;
 	
-	obj = l->data;
 	ti = evas_object_data_get(obj, "e_table_data");
 	if (ti->expand_w) expandw++;
 	if (ti->expand_h) expandh++;
      }
    if (expandw == 0)
      {
-	x += (w - minw) / 2;
 	w = minw;
      }
    if (expandh == 0)
      {
-	y += (h - minh) / 2;
 	h = minh;
      }
    x = sd->x;
    y = sd->y;
    if (sd->homogenous)
      {
-	for (l = sd->items; l; l = l->next)
+	EINA_LIST_FOREACH(sd->items, l, obj)
 	  {
 	     E_Table_Item *ti;
-	     Evas_Object *obj;
 	     Evas_Coord ww, hh, ow, oh;
 	     
-	     obj = l->data;
 	     ti = evas_object_data_get(obj, "e_table_data");
 	     
 	     xx = x + ((ti->col) * (w / (Evas_Coord)sd->size.cols));
@@ -366,12 +358,10 @@ _e_table_smart_reconfigure(E_Smart_Data *sd)
    else
      {
 	int i, ex, tot, need, num, dif, left, nx;
-	for (l = sd->items; l; l = l->next)
+	EINA_LIST_FOREACH(sd->items, l, obj)
 	  {
 	     E_Table_Item *ti;
-	     Evas_Object *obj;
 	     
-	     obj = l->data;
 	     ti = evas_object_data_get(obj, "e_table_data");	
 	     if (sd->size.cols < (ti->col + ti->colspan))
 	       sd->size.cols = ti->col + ti->colspan;
@@ -387,12 +377,10 @@ _e_table_smart_reconfigure(E_Smart_Data *sd)
 	     colsx = calloc(sd->size.cols, sizeof(int));
 	     rowsx = calloc(sd->size.rows, sizeof(int));
 	     
-	     for (l = sd->items; l; l = l->next)
+	     EINA_LIST_FOREACH(sd->items, l, obj)
 	       {
 		  E_Table_Item *ti;
-		  Evas_Object *obj;
 
-		  obj = l->data;
 		  ti = evas_object_data_get(obj, "e_table_data");
 		  for (i = ti->col; i < (ti->col + ti->colspan); i++)
 		    colsx[i] |= ti->expand_w;
@@ -400,12 +388,10 @@ _e_table_smart_reconfigure(E_Smart_Data *sd)
 		    rowsx[i] |= ti->expand_h;
 	       }
 	     
-	     for (l = sd->items; l; l = l->next)
+	     EINA_LIST_FOREACH(sd->items, l, obj)
 	       {
 		  E_Table_Item *ti;
-		  Evas_Object *obj;
 		  
-		  obj = l->data;
 		  ti = evas_object_data_get(obj, "e_table_data");
 		  
 		  /* handle horizontal */
@@ -581,13 +567,11 @@ _e_table_smart_reconfigure(E_Smart_Data *sd)
 		    }
 	       }
 	     
-	     for (l = sd->items; l; l = l->next)
+	     EINA_LIST_FOREACH(sd->items, l, obj)
 	       {
 		  E_Table_Item *ti;
-		  Evas_Object *obj;
 		  Evas_Coord ww, hh, ow, oh, i;
 		  
-		  obj = l->data;
 		  ti = evas_object_data_get(obj, "e_table_data");
 		  
 		  xx = x;
@@ -623,6 +607,7 @@ static void
 _e_table_smart_extents_calcuate(E_Smart_Data *sd)
 {
    Eina_List *l;
+   Evas_Object *obj;
    int minw, minh;
 
    sd->max.w = -1; /* max < 0 == unlimited */
@@ -634,13 +619,11 @@ _e_table_smart_extents_calcuate(E_Smart_Data *sd)
    minh = 0;
    if (sd->homogenous)
      {
-	for (l = sd->items; l; l = l->next)
+	EINA_LIST_FOREACH(sd->items, l, obj)
 	  {
 	     E_Table_Item *ti;
-	     Evas_Object *obj;
 	     int mw, mh;
 	     
-	     obj = l->data;
 	     ti = evas_object_data_get(obj, "e_table_data");	
 	     if (sd->size.cols < (ti->col + ti->colspan))
 	       sd->size.cols = ti->col + ti->colspan;
@@ -657,12 +640,10 @@ _e_table_smart_extents_calcuate(E_Smart_Data *sd)
    else
      {
 	int i, ex, tot, need, num, dif, left, nx;
-	for (l = sd->items; l; l = l->next)
+	EINA_LIST_FOREACH(sd->items, l, obj)
 	  {
 	     E_Table_Item *ti;
-	     Evas_Object *obj;
 	     
-	     obj = l->data;
 	     ti = evas_object_data_get(obj, "e_table_data");	
 	     if (sd->size.cols < (ti->col + ti->colspan))
 	       sd->size.cols = ti->col + ti->colspan;
@@ -678,12 +659,10 @@ _e_table_smart_extents_calcuate(E_Smart_Data *sd)
 	     colsx = calloc(sd->size.cols, sizeof(int));
 	     rowsx = calloc(sd->size.rows, sizeof(int));
 	     
-	     for (l = sd->items; l; l = l->next)
+	     EINA_LIST_FOREACH(sd->items, l, obj)
 	       {
 		  E_Table_Item *ti;
-		  Evas_Object *obj;
 
-		  obj = l->data;
 		  ti = evas_object_data_get(obj, "e_table_data");
 		  for (i = ti->col; i < (ti->col + ti->colspan); i++)
 		    colsx[i] |= ti->expand_w;
@@ -691,12 +670,10 @@ _e_table_smart_extents_calcuate(E_Smart_Data *sd)
 		    rowsx[i] |= ti->expand_h;
 	       }
 	     
-	     for (l = sd->items; l; l = l->next)
+	     EINA_LIST_FOREACH(sd->items, l, obj)
 	       {
 		  E_Table_Item *ti;
-		  Evas_Object *obj;
 		  
-		  obj = l->data;
 		  ti = evas_object_data_get(obj, "e_table_data");
 		  
 		  /* handle horizontal */
@@ -842,6 +819,9 @@ _e_table_smart_init(void)
 	       NULL,
 	       NULL,
 	       NULL,
+	       NULL,
+	       NULL,
+	       NULL,
 	       NULL
 	  };
 	_e_smart = evas_smart_class_new(&sc);
@@ -880,7 +860,7 @@ _e_table_smart_del(Evas_Object *obj)
      {
 	Evas_Object *child;
 	
-	child = sd->items->data;
+	child = eina_list_data_get(sd->items);
 	e_table_unpack(child);
      }
    e_table_thaw(obj);
@@ -899,16 +879,17 @@ _e_table_smart_move(Evas_Object *obj, Evas_Coord x, Evas_Coord y)
    if ((x == sd->x) && (y == sd->y)) return;
      {
 	Eina_List *l;
+	Evas_Object *item;
 	Evas_Coord dx, dy;
 	
 	dx = x - sd->x;
 	dy = y - sd->y;
-	for (l = sd->items; l; l = l->next)
+	EINA_LIST_FOREACH(sd->items, l, item)
 	  {
 	     Evas_Coord ox, oy;
 	     
-	     evas_object_geometry_get(l->data, &ox, &oy, NULL, NULL);
-	     evas_object_move(l->data, ox + dx, oy + dy);
+	     evas_object_geometry_get(item, &ox, &oy, NULL, NULL);
+	     evas_object_move(item, ox + dx, oy + dy);
 	  }
      }
    sd->x = x;
