@@ -47,9 +47,9 @@ static int _wheel_binding_sort_cb(const void *d1, const void *d2);
 /********* grab window **********/
 static void _grab_wnd_show(E_Config_Dialog_Data *cfdata);
 static void _grab_wnd_hide(E_Config_Dialog_Data *cfdata);
-static int _grab_mouse_down_cb(void *data, int type, void *event);
-static int _grab_mouse_wheel_cb(void *data, int type, void *event);
-static int _grab_key_down_cb(void *data, int type, void *event);
+static Eina_Bool _grab_mouse_down_cb(void *data, int type, void *event);
+static Eina_Bool _grab_mouse_wheel_cb(void *data, int type, void *event);
+static Eina_Bool _grab_key_down_cb(void *data, int type, void *event);
 
 struct _E_Config_Dialog_Data
 {
@@ -93,13 +93,13 @@ struct _E_Config_Dialog_Data
     } gui;
 };
 
-EAPI E_Config_Dialog *
+E_Config_Dialog *
 e_int_config_mousebindings(E_Container *con, const char *params __UNUSED__)
 {
    E_Config_Dialog *cfd;
    E_Config_Dialog_View *v;
    
-   if (e_config_dialog_find("E", "_config_mousebindings_dialog")) return NULL;
+   if (e_config_dialog_find("E", "keyboard_and_mouse/mouse_bindings")) return NULL;
    v = E_NEW(E_Config_Dialog_View, 1);
    
    v->create_cfdata = _create_data;
@@ -109,8 +109,8 @@ e_int_config_mousebindings(E_Container *con, const char *params __UNUSED__)
    v->override_auto_apply = 0;
    
    cfd = e_config_dialog_new(con,
-			     _("Mouse Binding Settings"),
-			     "E", "_config_mousebindings_dialog",
+			     _("Mouse Bindings Settings"),
+			     "E", "keyboard_and_mouse/mouse_bindings",
 			     "preferences-desktop-mouse", 0, v, NULL);
    return cfd;
 }
@@ -139,8 +139,8 @@ _fill_data(E_Config_Dialog_Data *cfdata)
 	eb2->button = eb->button;
 	eb2->modifiers = eb->modifiers;
 	eb2->any_mod = eb->any_mod;
-	eb2->action = eb->action == NULL ? NULL : eina_stringshare_add(eb->action);
-	eb2->params = eb->params == NULL ? NULL : eina_stringshare_add(eb->params);
+	eb2->action = !eb->action ? NULL : eina_stringshare_add(eb->action);
+	eb2->params = !eb->params ? NULL : eina_stringshare_add(eb->params);
 
 	cfdata->binding.mouse = eina_list_append(cfdata->binding.mouse, eb2);
      }
@@ -153,8 +153,8 @@ _fill_data(E_Config_Dialog_Data *cfdata)
 	bw2->z = bw->z;
 	bw2->modifiers = bw->modifiers;
 	bw2->any_mod = bw->any_mod;
-	bw2->action = bw->action == NULL ? NULL : eina_stringshare_add(bw->action);
-	bw2->params = bw->params == NULL ? NULL : eina_stringshare_add(bw->params);
+	bw2->action = !bw->action ? NULL : eina_stringshare_add(bw->action);
+	bw2->params = !bw->params ? NULL : eina_stringshare_add(bw->params);
 
 	cfdata->binding.wheel = eina_list_append(cfdata->binding.wheel, bw2);
      }
@@ -173,7 +173,7 @@ _create_data(E_Config_Dialog *cfd)
 }
 
 static void
-_free_data(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
+_free_data(E_Config_Dialog *cfd __UNUSED__, E_Config_Dialog_Data *cfdata)
 {
    E_Config_Binding_Mouse *eb;
    E_Config_Binding_Wheel *bw;
@@ -201,7 +201,7 @@ _free_data(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
 }
 
 static int
-_basic_apply_data(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
+_basic_apply_data(E_Config_Dialog *cfd __UNUSED__, E_Config_Dialog_Data *cfdata)
 { 
    Eina_List *l;
    E_Config_Binding_Mouse *eb, *eb2;
@@ -226,8 +226,8 @@ _basic_apply_data(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
 	eb2->button = eb->button;
 	eb2->modifiers = eb->modifiers;
 	eb2->any_mod = eb->any_mod;
-	eb2->action = eb->action == NULL ? NULL : eina_stringshare_add(eb->action);
-	eb2->params = eb->params == NULL ? NULL : eina_stringshare_add(eb->params);
+	eb2->action = !eb->action ? NULL : eina_stringshare_add(eb->action);
+	eb2->params = !eb->params ? NULL : eina_stringshare_add(eb->params);
 
 	e_config->mouse_bindings = eina_list_append(e_config->mouse_bindings, eb2);
 	e_bindings_mouse_add(eb2->context, eb2->button, eb2->modifiers, eb2->any_mod,
@@ -251,8 +251,8 @@ _basic_apply_data(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
 	bw2->z = bw->z;
 	bw2->modifiers = bw->modifiers;
 	bw2->any_mod = bw->any_mod;
-	bw2->action = bw->action == NULL ? NULL : eina_stringshare_add(bw->action);
-	bw2->params = bw->params == NULL ? NULL : eina_stringshare_add(bw->params);
+	bw2->action = !bw->action ? NULL : eina_stringshare_add(bw->action);
+	bw2->params = !bw->params ? NULL : eina_stringshare_add(bw->params);
 
 	e_config->wheel_bindings = eina_list_append(e_config->wheel_bindings, bw2);
 	e_bindings_wheel_add(bw2->context, bw2->direction, bw2->z, bw2->modifiers,
@@ -275,7 +275,7 @@ _basic_create_widgets(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cf
    ot = e_widget_frametable_add(evas, _("Mouse Bindings"), 0);
    ob = e_widget_ilist_add(evas, 32, 32, &(cfdata->locals.binding));
    cfdata->gui.o_binding_list = ob;
-   e_widget_min_size_set(ob, 200, 200);
+   e_widget_size_min_set(ob, 200, 200);
    e_widget_frametable_object_append(ot, ob, 0, 0, 2, 1, 1, 1, 1, 1);
 
    ob = e_widget_button_add(evas, _("Add Binding"), NULL, _add_mouse_binding_cb, cfdata, NULL);
@@ -292,7 +292,7 @@ _basic_create_widgets(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cf
    cfdata->gui.o_del_all = ob;
    e_widget_disabled_set(ob, 1);
    e_widget_frametable_object_append(ot, ob, 1, 2, 1, 1, 1, 0, 1, 0);
-   ob = e_widget_button_add(evas, _("Restore Mouse and Wheel Binding Defaults"), "enlightenment",
+   ob = e_widget_button_add(evas, _("Restore Default Bindings"), "enlightenment",
 			    _restore_mouse_binding_defaults_cb, cfdata, NULL);
    e_widget_frametable_object_append(ot, ob, 0, 3, 2, 1, 1, 0, 1, 0);
    e_widget_list_object_append(o, ot, 1, 1, 0.5);
@@ -301,7 +301,7 @@ _basic_create_widgets(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cf
    of = e_widget_framelist_add(evas, _("Action"), 0);
    ob = e_widget_ilist_add(evas, 24, 24, &(cfdata->locals.action));
    cfdata->gui.o_action_list = ob;
-   e_widget_min_size_set(ob, 200, 200);
+   e_widget_size_min_set(ob, 200, 200);
    e_widget_framelist_object_append(of, ob);
    e_widget_table_object_append(ot, of, 0, 0, 3, 1, 1, 1, 1, 1);
    
@@ -399,7 +399,7 @@ _fill_actions_list(E_Config_Dialog_Data *cfdata)
 
 /******************* Callbacks *************/
 static void
-_add_mouse_binding_cb(void *data, void *data2)
+_add_mouse_binding_cb(void *data, void *data2 __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
 
@@ -411,7 +411,7 @@ _add_mouse_binding_cb(void *data, void *data2)
 }
 
 static void
-_modify_mouse_binding_cb(void *data, void *data2)
+_modify_mouse_binding_cb(void *data, void *data2 __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
 
@@ -452,7 +452,7 @@ _binding_change_cb(void *data)
 }
 
 static void
-_delete_all_mouse_binding_cb(void *data, void *data2)
+_delete_all_mouse_binding_cb(void *data, void *data2 __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
    E_Config_Binding_Mouse *eb;
@@ -489,7 +489,7 @@ _delete_all_mouse_binding_cb(void *data, void *data2)
 }
 
 static void
-_delete_mouse_binding_cb(void *data, void *data2)
+_delete_mouse_binding_cb(void *data, void *data2 __UNUSED__)
 {
    Eina_List *l;
    int sel, n;
@@ -556,7 +556,7 @@ _delete_mouse_binding_cb(void *data, void *data2)
 }
 
 static void
-_restore_mouse_binding_defaults_cb(void *data, void *data2)
+_restore_mouse_binding_defaults_cb(void *data, void *data2 __UNUSED__)
 {
    E_Config_Binding_Mouse *eb;
    E_Config_Binding_Wheel *bw;
@@ -1028,8 +1028,8 @@ _auto_apply_changes(E_Config_Dialog_Data *cfdata)
 	params = &(bw->params);
      } 
    
-   eina_stringshare_del(*action); 
-   eina_stringshare_del(*params); 
+   if (*action) eina_stringshare_del(*action); 
+   if (*params) eina_stringshare_del(*params); 
    *action = NULL; 
    *params = NULL;
 
@@ -1059,7 +1059,7 @@ _auto_apply_changes(E_Config_Dialog_Data *cfdata)
 	  ok = 0;
 
 	if (ok)
-	  *params = eina_stringshare_ref(cfdata->locals.params);
+	  *params = eina_stringshare_add(cfdata->locals.params);
      }
 }
 
@@ -1188,7 +1188,7 @@ _helper_wheel_name_get(E_Config_Binding_Wheel *bw)
 static char *
 _helper_modifier_name_get(int mod)
 {
-   char mods[1024]="";
+   char mods[1024] = "";
 
    if (mod & E_BINDING_MODIFIER_SHIFT)
      snprintf(mods, sizeof(mods), "SHIFT");
@@ -1314,8 +1314,8 @@ _grab_wnd_hide(E_Config_Dialog_Data *cfdata)
    cfdata->locals.dia = NULL;
 }
 
-static int
-_grab_mouse_down_cb(void *data, int type, void *event)
+static Eina_Bool
+_grab_mouse_down_cb(void *data, __UNUSED__ int type, void *event)
 {
    Eina_List *l;
    E_Config_Dialog_Data *cfdata;
@@ -1328,7 +1328,7 @@ _grab_mouse_down_cb(void *data, int type, void *event)
    ev = event;
    cfdata = data;
 
-   if (ev->window != cfdata->locals.bind_win) return 1; 
+   if (ev->window != cfdata->locals.bind_win) return ECORE_CALLBACK_PASS_ON;
 
    if (ev->modifiers & ECORE_EVENT_MODIFIER_SHIFT)
      mod |= E_BINDING_MODIFIER_SHIFT;
@@ -1413,11 +1413,11 @@ _grab_mouse_down_cb(void *data, int type, void *event)
    _update_buttons(cfdata);
    _grab_wnd_hide(cfdata);
 
-   return 1;
+   return ECORE_CALLBACK_PASS_ON;
 }
 
-static int 
-_grab_mouse_wheel_cb(void *data, int type, void *event)
+static Eina_Bool
+_grab_mouse_wheel_cb(void *data, __UNUSED__ int type, void *event)
 {
    Eina_List *l;
    E_Config_Binding_Wheel *bw = NULL;
@@ -1429,7 +1429,7 @@ _grab_mouse_wheel_cb(void *data, int type, void *event)
    ev = event;
    cfdata = data;
 
-   if (ev->window != cfdata->locals.bind_win) return 1;
+   if (ev->window != cfdata->locals.bind_win) return ECORE_CALLBACK_PASS_ON;
 
    if (ev->modifiers & ECORE_EVENT_MODIFIER_SHIFT)
      mod |= E_BINDING_MODIFIER_SHIFT;
@@ -1528,18 +1528,18 @@ _grab_mouse_wheel_cb(void *data, int type, void *event)
    _update_buttons(cfdata);
 
    _grab_wnd_hide(cfdata);
-   return 1;
+   return ECORE_CALLBACK_PASS_ON;
 }
 
-static int
-_grab_key_down_cb(void *data, int type, void *event)
+static Eina_Bool
+_grab_key_down_cb(void *data, __UNUSED__ int type, void *event)
 {
    E_Config_Dialog_Data *cfdata;
    Ecore_Event_Key *ev = event;
 
    cfdata = data;
 
-   if (ev->window != cfdata->locals.bind_win) return 1;
+   if (ev->window != cfdata->locals.bind_win) return ECORE_CALLBACK_PASS_ON;
 
    if (!strcmp(ev->keyname, "Escape") &&
        !(ev->modifiers & ECORE_EVENT_MODIFIER_SHIFT) &&
@@ -1549,5 +1549,5 @@ _grab_key_down_cb(void *data, int type, void *event)
      { 
 	_grab_wnd_hide(cfdata);
      }
-   return 1;
+   return ECORE_CALLBACK_PASS_ON;
 }
