@@ -1,11 +1,6 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #include "e.h"
 #include "e_mod_main.h"
 
-/***************************************************************************/
-/**/
 /* gadcon requirements */
 static E_Gadcon_Client *_gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style);
 static void _gc_shutdown(E_Gadcon_Client *gcc);
@@ -24,13 +19,8 @@ static const E_Gadcon_Client_Class _gadcon_class =
      },
    E_GADCON_CLIENT_STYLE_PLAIN
 };
-/**/
-/***************************************************************************/
 
-/***************************************************************************/
-/**/
 /* actual module specifics */
-
 typedef struct _Instance Instance;
 
 struct _Instance
@@ -51,22 +41,23 @@ _gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style)
    Evas_Object *o;
    E_Gadcon_Client *gcc;
    Instance *inst;
-   
+
    inst = E_NEW(Instance, 1);
-   
+
    o = edje_object_add(gc->evas);
-   e_theme_edje_object_set(o, "base/theme/modules/start", "e/modules/start/main");
+   e_theme_edje_object_set(o, "base/theme/modules/start", 
+                           "e/modules/start/main");
    edje_object_signal_emit(o, "e,state,unfocused", "e");
-   
+
    gcc = e_gadcon_client_new(gc, name, id, style, o);
    gcc->data = inst;
-   
+
    inst->gcc = gcc;
    inst->o_button = o;
    inst->main_menu = NULL;
-   
+
    e_gadcon_client_util_menu_attach(gcc);
-   
+
    evas_object_event_callback_add(o, EVAS_CALLBACK_MOUSE_DOWN,
 				  _button_cb_mouse_down, inst);
    return gcc;
@@ -76,7 +67,7 @@ static void
 _gc_shutdown(E_Gadcon_Client *gcc)
 {
    Instance *inst;
-   
+
    inst = gcc->data;
    if (inst->main_menu)
      {
@@ -89,11 +80,11 @@ _gc_shutdown(E_Gadcon_Client *gcc)
 }
     
 static void
-_gc_orient(E_Gadcon_Client *gcc, E_Gadcon_Orient orient)
+_gc_orient(E_Gadcon_Client *gcc, E_Gadcon_Orient orient __UNUSED__)
 {
    Instance *inst;
    Evas_Coord mw, mh;
-   
+
    inst = gcc->data;
    mw = 0, mh = 0;
    edje_object_size_min_get(inst->o_button, &mw, &mh);
@@ -106,17 +97,17 @@ _gc_orient(E_Gadcon_Client *gcc, E_Gadcon_Orient orient)
 }
    
 static char *
-_gc_label(E_Gadcon_Client_Class *client_class)
+_gc_label(E_Gadcon_Client_Class *client_class __UNUSED__)
 {
    return _("Start");
 }
 
 static Evas_Object *
-_gc_icon(E_Gadcon_Client_Class *client_class, Evas *evas)
+_gc_icon(E_Gadcon_Client_Class *client_class __UNUSED__, Evas *evas)
 {
    Evas_Object *o;
-   char buf[4096];
-   
+   char buf[PATH_MAX];
+
    o = edje_object_add(evas);
    snprintf(buf, sizeof(buf), "%s/e-module-start.edj",
 	    e_module_dir_get(start_module));
@@ -125,22 +116,17 @@ _gc_icon(E_Gadcon_Client_Class *client_class, Evas *evas)
 }
 
 static const char *
-_gc_id_new(E_Gadcon_Client_Class *client_class)
+_gc_id_new(E_Gadcon_Client_Class *client_class __UNUSED__)
 {
    return _gadcon_class.name;
 }
 
-/**/
-/***************************************************************************/
-
-/***************************************************************************/
-/**/
 static void
-_button_cb_mouse_down(void *data, Evas *e, Evas_Object *obj, void *event_info)
+_button_cb_mouse_down(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info)
 {
    Instance *inst;
    Evas_Event_Mouse_Down *ev;
-   
+
    inst = data;
    ev = event_info;
    if (ev->button == 1)
@@ -158,10 +144,9 @@ _button_cb_mouse_down(void *data, Evas *e, Evas_Object *obj, void *event_info)
 	if (inst->main_menu)
 	  {
 	     int dir;
-	     
+
 	     e_menu_post_deactivate_callback_set(inst->main_menu,
-						 _menu_cb_post,
-						 inst);
+						 _menu_cb_post, inst);
 	     switch (inst->gcc->gadcon->orient)
 	       {
 		case E_GADCON_ORIENT_TOP:
@@ -207,22 +192,21 @@ _button_cb_mouse_down(void *data, Evas *e, Evas_Object *obj, void *event_info)
 		  dir = E_MENU_POP_DIRECTION_AUTO;
 		  break;
 	       }
-	     
+
 	     e_gadcon_locked_set(inst->gcc->gadcon, 1);
 	     e_menu_activate_mouse(inst->main_menu,
 				   e_util_zone_current_get(e_manager_current_get()),
-				   x, y, w, h,
-				   dir, ev->timestamp);
+				   x, y, w, h, dir, ev->timestamp);
 	     edje_object_signal_emit(inst->o_button, "e,state,focused", "e");
 	  }
      }
 }
 
 static void
-_menu_cb_post(void *data, E_Menu *m)
+_menu_cb_post(void *data, E_Menu *m __UNUSED__)
 {
    Instance *inst;
-   
+
    inst = data;
    if (!inst->main_menu) return;
    e_gadcon_locked_set(inst->gcc->gadcon, 0);
@@ -230,11 +214,7 @@ _menu_cb_post(void *data, E_Menu *m)
    e_object_del(E_OBJECT(inst->main_menu));
    inst->main_menu = NULL;
 }
-/**/
-/***************************************************************************/
 
-/***************************************************************************/
-/**/
 /* module setup */
 EAPI E_Module_Api e_modapi = 
 {
@@ -246,26 +226,20 @@ EAPI void *
 e_modapi_init(E_Module *m)
 {
    start_module = m;
-   
    e_gadcon_provider_register(&_gadcon_class);
    return m;
 }
 
 EAPI int
-e_modapi_shutdown(E_Module *m)
+e_modapi_shutdown(E_Module *m __UNUSED__)
 {
    start_module = NULL;
-   
    e_gadcon_provider_unregister(&_gadcon_class);
    return 1;
 }
 
 EAPI int
-e_modapi_save(E_Module *m)
+e_modapi_save(E_Module *m __UNUSED__)
 {
    return 1;
 }
-
-/**/
-/***************************************************************************/
-
